@@ -1390,6 +1390,15 @@ class phodevi_gpu extends phodevi_device_interface
 			}
 		}
 
+		if(empty($info) && isset(phodevi::$vfs->xorg_log))
+		{
+			// ARM Mali DDX driver detection fallback
+			if(strpos(phodevi::$vfs->xorg_log, 'MALI(') !== false)
+			{
+				$info = 'ARM Mali';
+			}
+		}
+
 		if(($bracket_open = strpos($info, '[')) !== false)
 		{
 			// Report only the information inside the brackets if it's more relevant...
@@ -1433,6 +1442,20 @@ class phodevi_gpu extends phodevi_device_interface
 			$info .= ' ' . $video_ram . 'MB';
 		}
 
+		if(empty($info) && is_dir('/sys/class/drm/card0/device/driver/pvrsrvkm'))
+		{
+			$info = 'PowerVR';
+		}
+		if(empty($info) && is_readable('/sys/class/graphics/fb0/name'))
+		{
+			// Last possible fallback...
+			$info = str_replace(' FB', '', pts_file_io::file_get_contents('/sys/class/graphics/fb0/name'));
+		}
+		/*if(empty($info))
+		{
+			$info = 'Unknown';
+		}*/
+
 		return $info;
 	}
 }
